<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:mdq="http://www.matrixscience.com/xmlns/schema/distiller_quantitation_2"
  xmlns:mqm="http://www.matrixscience.com/xmlns/schema/quantitation_2"
  xmlns:textu="http://www.matrixscience.com/xmlns/xslt/text_utils"
  xmlns:js_calc="http://www.matrixscience.com/xmlns/schema/js_calcs"
  extension-element-prefixes="js_calc">

  <xsl:import href="utils/text_utils.xslt" />
  <xsl:import href="utils/svg_utils.xslt" />
  <xsl:output method="html" />

  <xsl:template name="report" match="/mdq:quantitationResults">

  <!-- supported protocols: precursor replicate -->  

  <!-- Misc. variables  -->
  
    <xsl:variable name="ratioName" select="mqm:quantitation/mqm:method/mqm:report_ratio/@name" />
    <xsl:variable name="componentName" select="mqm:quantitation/mqm:method/mqm:component/@name" />
  
  <!-- HTML header  -->
  
    <html xmlns="http://www.w3.org/1999/xhtml">
      <head>
        <title>Table of Peptides for Copy and Paste</title>
        <link href="matrixscience.css" rel="stylesheet" type="text/css" />
        <meta http-equiv="content-type" content="text/html; charset=utf-8" />
      </head>
      <body style="margin-left:10px; margin-right:10px; margin-top:10px; margin-bottom:10px">

        <h2>Table of Peptides for Copy and Paste</h2>

  <!-- Output header text  -->
  
        <xsl:call-template name="textu:printHeader" />
          
  <!-- Tabulated protein and peptide data  -->

        <p /><table border="1" cellspacing="0" cellpadding="2">
          <tr bgcolor="#9acd32">
            <th align="left">protHit</th>
            <th align="left">Member</th>
            <th align="left">Accession</th>
            <th align="left">Score</th>
            <th align="left">Mass</th>
            <th align="left">pepMatch</th>
            <th align="left">z</th>
            <th align="left">Sequence</th>
            <th align="left">Fraction</th>
            <th align="left">Correlation</th>
            <th align="left">Modifications</th>
            <xsl:for-each select="$componentName">
              <th align="left">Ident(<xsl:value-of select="." />)</th>
              <th align="left">Start(<xsl:value-of select="." />)</th>
              <th align="left">End(<xsl:value-of select="." />)</th>
              <th align="left">Intensity(<xsl:value-of select="." />)</th>
            </xsl:for-each>
          </tr>
          <xsl:for-each select="mdq:proteinHit">
            <xsl:variable name="proteinHitNode" select="." />
            <xsl:variable name="hitNum" select="number(@hit)" />
            <xsl:variable name="memberNum" select="number(@memberNumber)" />
            <xsl:for-each select="mdq:reftoPeptideMatch">
              <xsl:variable name="pep_ref" select="." />
              <xsl:variable name="peptideMatchNode" 
                select="/mdq:quantitationResults/mdq:peptideMatch[@id=$pep_ref]" />
              <xsl:variable name="matchNum" select="position()" />
              <tr>
                <td><xsl:value-of select="$hitNum" /></td>
                <xsl:choose>
                  <xsl:when test="$memberNum &gt; 0">
                    <td><xsl:value-of select="$memberNum" /></td>
                  </xsl:when>
                  <xsl:otherwise>
                    <td><xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text></td>
                  </xsl:otherwise>
                </xsl:choose>
                <td nowrap="true"><xsl:call-template name="textu:decode">
                <xsl:with-param name="encoded" select="$proteinHitNode/@accession" />
                </xsl:call-template></td>
                <td><xsl:value-of select="$proteinHitNode/@score" /></td>
                <td><xsl:value-of select="$proteinHitNode/@mass" /></td>
                <td><xsl:value-of select="$matchNum" /></td>
                <td><xsl:value-of select="$peptideMatchNode/@chargeState" /></td>
                <td><xsl:value-of select="$peptideMatchNode/mdq:partner/@peptideString" /></td>
                <td><xsl:value-of 
                  select="js_calc:toPrecision(string($peptideMatchNode/mdq:chargeStateData/@matchedFraction),4)" /></td>
                <td><xsl:value-of 
                  select="js_calc:toPrecision(string($peptideMatchNode/mdq:chargeStateData/@matchedRho),4)" /></td>
                <td nowrap="true"><xsl:call-template name="textu:decode">
                <xsl:with-param name="encoded" select="$peptideMatchNode/@readableVarmodStr" />
                </xsl:call-template><xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text></td>
                <xsl:for-each select="$componentName">
                  <xsl:variable name="cName" select="." />
                  <xsl:for-each select="$peptideMatchNode/mdq:partner[(@component=$cName)]">
                    <td><xsl:value-of select="@partnerIdentified" /></td>
                    <td><xsl:value-of select="js_calc:toPrecision(string(mdq:xic/@rtXICPeakStart),7)" /></td>
                    <td><xsl:value-of select="js_calc:toPrecision(string(mdq:xic/@rtXICPeakEnd),7)" /></td>
                    <td><xsl:value-of select="js_calc:toPrecision(string(mdq:absoluteValue/@value),7)" /></td>
                  </xsl:for-each>
                </xsl:for-each>
              </tr>
            </xsl:for-each>
          </xsl:for-each>
        </table>

      </body>
    </html>
  </xsl:template>

</xsl:stylesheet>

